@@ -4,11 +4,11 @@
 #' This function is invoked and controlled by \code{plot.prodlim}.
 #' 
 #' This function should not be called directly. The arguments can be specified
-#' as \code{atRisk.arg} in the call to \code{plot.prodim}.
+#' as \code{atRisk.arg} in the call to \code{plot.prodlim}.
 #' 
 #' @param x an object of class `prodlim' as returned by the
 #' \code{prodlim} function.
-#' @param newdata see \code{plot.prodim}
+#' @param newdata see \code{plot.prodlim}
 #' @param times Where to compute the atrisk numbers.
 #' @param line Distance of the atrisk numbers from the inner plot.
 #' @param col The color of the text.
@@ -52,7 +52,7 @@ atRisk <- function(x,
                    ...){
     if (missing(times)) times <- seq(0,x$maxtime,x$maxtime/10)
     if (x$model=="competing.risks"){
-        px <- lifeTab(object=x,times=times,cause=1,newdata=newdata,stats=NULL)[[1]]
+        px <- lifeTab(object=x,times=times,cause=getStates(x)[1],newdata=newdata,stats=NULL)[[1]]
     }
     else if (x$model=="survival"){
         px <- lifeTab(object=x,times=times,newdata=newdata,stats=NULL)
