@@ -8,7 +8,8 @@
 #' @aliases jackknife jackknife.survival jackknife.competing.risks
 #' @param object Object of class \code{"prodlim"}.
 #' @param times Time points at which to compute pseudo values.
-#' @param cause For competing risks the cause of failure.
+#' @param cause Character (other classes are converted with \code{as.character}).
+#' For competing risks the cause of failure.
 #' @param keepResponse If \code{TRUE} add the model response,
 #' i.e. event time, event status, etc. to the result.
 #' @param ... not used
@@ -25,11 +26,11 @@
 ##' 
 ##' d=SimSurv(20) 
 ##' f=prodlim(Hist(time,status)~1,data=d) 
-##' jackknife(f,times=c(30,50))
+##' jackknife(f,times=c(3,5))
 ##' 
 ##' ## in some situations it may be useful to attach the
 ##' ## the event time history to the result
-##' jackknife(f,times=c(30,50),keepResponse=TRUE)
+##' jackknife(f,times=c(3,5),keepResponse=TRUE)
 ##' 
 ##' # pseudo-values for competing risk models
 ##' d=SimCompRisk(10) 
@@ -39,15 +40,18 @@
 ##' 
 #' @export
 jackknife <- function(object,times,cause,keepResponse=FALSE,...){
-  if (object$model=="survival")
-    jackknife.survival(object=object,times=times,keepResponse=keepResponse,...)
-  else if (object$model=="competing.risks")
-    jackknife.competing.risks(object=object,
-                              times=times,
-                              cause=cause,
-                              keepResponse=keepResponse,
-                              ...)
-  else stop("No method for jackknifing this object.")
+    if (object$model=="survival")
+        jackknife.survival(object=object,times=times,keepResponse=keepResponse,...)
+    else if (object$model=="competing.risks"){
+        if (!missing(cause)) cause <- checkCauses(cause,object)
+        else cause <- attr(object$model.response,which="states")[[1]]
+        jackknife.competing.risks(object=object,
+                                  times=times,
+                                  cause=cause,
+                                  keepResponse=keepResponse,
+                                  ...)
+    }
+    else stop("No method for jackknifing this object.")
 }
 
 #' @export
